#  Copyright (C) 2023
#  ABM, Moscow
#
#  UNPUBLISHED PROPRIETARY MATERIAL.
#  ALL RIGHTS RESERVED.
#
#  Authors: Revva Konstantin <k.revva@abm-jsc.ru>

from obstruction_detector_connector.shift_analyze_result import ObstructionAnalyzeResult
from obstruction_detector_connector.shift_detector_connector import ObstructionDetectorConnector
from detector_connector import DetectorHttpConnector as ObstructionDetectorHttpConnector
from obstruction_detector_connector.shift_detector_kafka_connector import ObstructionDetectorKafkaConnector
